/********************************************************************/
// WIFI libs
// from https://arduino.stackexchange.com/questions/45625/simple-get-request-with-esp8266httpclient
#include <ESP8266WiFi.h>
#include <ESP8266HTTPClient.h>
#define SSID "*************"
#define PASSWORD "****************"

/********************************************************************/
// 1-wire libs
// from https://create.arduino.cc/projecthub/TheGadgetBoy/ds18b20-digital-temperature-sensor-and-arduino-9cc806
#include <OneWire.h>
#include <DallasTemperature.h>
#define ONE_WIRE_BUS 0     //D8 on WeMOS D1

// pin for LED
#define LED_PIN  2      //D9 on WeMOS D1


// Setup a oneWire instance to communicate with any OneWire devices
// (not just Maxim/Dallas temperature ICs)
OneWire oneWire(ONE_WIRE_BUS);
DallasTemperature sensors(&oneWire);


//pulse counter
// from https://forum.arduino.cc/index.php?topic=541116.0
#define COUNT_PIN  5  // D3 on WeMOS D1
unsigned int pulse = 0; // Variable for saving pulses count.
int var = 0;
void ICACHE_RAM_ATTR count_pulse ();

void setup() {
  Serial.begin(115200);
  Serial.println();

  WiFi.begin(SSID, PASSWORD);

  Serial.print("Connecting");
  while (WiFi.status() != WL_CONNECTED)
  {
    delay(500);
    Serial.print(".");
  }
  Serial.println();

  Serial.print("Connected, IP address: ");
  Serial.println(WiFi.localIP());

  // initialize GPIO 2 as an output.
  pinMode(LED_PIN, OUTPUT);

  sensors.begin();

  //initialise GPIO for counter
  pinMode(COUNT_PIN, INPUT);
  attachInterrupt(digitalPinToInterrupt(COUNT_PIN), count_pulse, RISING);

}

String temp;


// the loop function runs over and over again forever
void loop() {
  // one-wire commands
  sensors.requestTemperatures(); // Send the command to get temperature readings
  temp = String(sensors.getTempCByIndex(0));
  Serial.println(temp + "\t" + pulse);

  HTTPClient http;
  http.begin("http://172.2**********/emoncms/input/post.json?node=11&json={temp:" + temp +",rain:" + pulse +"}&apikey=**********************");
  int httpCode = http.GET();
  //Serial.println(httpCode);

  digitalWrite(LED_PIN, LOW);   // turn the LED on (HIGH is the voltage level)
  delay(150);               // wait for 0.15 second

  digitalWrite(LED_PIN, HIGH);    // turn the LED off by making the voltage LOW
  delay(10000);               // wait for 10 seconds
}


void count_pulse()
{
  static unsigned long last_interrupt_time = 0;
  unsigned long interrupt_time = millis();

  if(interrupt_time - last_interrupt_time > 200)
    {
    pulse++;
    }

  last_interrupt_time = interrupt_time;
} 
